@@ -282,7 +282,7 @@ data:extend(
     working_sound =
     {
       sound = {filename = "__base__/sound/electric-mining-drill.ogg", volume = 1.0, advanced_volume_control = {attenuation = "exponential"}},
-      max_sounds_per_type = 4,
+      max_sounds_per_prototype = 4,
       fade_in_ticks = 4,
       fade_out_ticks = 20
     },
@@ -796,9 +796,9 @@ data:extend(
               filename = "__base__/graphics/entity/electric-mining-drill/electric-mining-drill-S-wet.png",
               line_length = 1,
               width = 192,
-              height = 208,
+              height = 210,
               animation_speed = electric_drill_animation_speed,
-              shift = util.by_pixel(1, -5),
+              shift = util.by_pixel(1, -5.5),
               repeat_count = 5,
               scale = 0.5
             },
@@ -1795,7 +1795,7 @@ data:extend(
       height = 12
     },
     monitor_visualization_tint = {78, 173, 255},
-    base_render_layer = "lower-object-above-shadow",
+    base_render_layer = "object",
     base_picture =
     {
       sheets =
@@ -1857,9 +1857,8 @@ data:extend(
     close_sound = {filename = "__base__/sound/open-close/pumpjack-close.ogg", volume = 0.5},
     working_sound =
     {
-      sound = {filename = "__base__/sound/pumpjack.ogg", volume = 0.7},
-      max_sounds_per_type = 3,
-      audible_distance_modifier = 0.6,
+      sound = {filename = "__base__/sound/pumpjack.ogg", volume = 0.7, audible_distance_modifier = 0.6},
+      max_sounds_per_prototype = 3,
       fade_in_ticks = 4,
       fade_out_ticks = 10
     },
