@@ -142,7 +142,9 @@ function util.moveposition(position, direction, distance)
   local direction_vector = util.direction_vectors[direction]
   if not direction_vector then error(direction .. " is not a valid or supported direction") end
 
-  return {position[1] + direction_vector[1] * distance, position[2] + direction_vector[2] * distance}
+  local x = position[1] or position.x
+  local y = position[2] or position.y
+  return {x + direction_vector[1] * distance, y + direction_vector[2] * distance}
 end
 
 -- orientation of 1 = 360 degrees
@@ -150,7 +152,8 @@ function util.rotate_position(position, orientation)
   local x = position[1] or position.x
   local y = position[2] or position.y
   local radians = orientation * 2 * math.pi
-  return {x = y * math.sin(radians) + x * math.cos(radians), y = y * math.cos(radians) + x * math.sin(radians)}
+  return {x = x * math.cos(radians) - y * math.sin(radians),
+          y = x * math.sin(radians) + y * math.cos(radians)}
 end
 
 function util.oppositedirection(direction)
@@ -354,7 +357,7 @@ function util.combine_icons(icons1, icons2, inputs, default_icon_size)
     local icon = {}
     icon.icon = icon_to_add.icon
     icon.icon_size = icon_to_add.icon_size or default_icon_size or error("No icon size defined for icon \n"..serpent.block(icon))
-    icon.scale = scale * ((icon_to_add.scale or 32.0) / icon.icon_size)
+    icon.scale = scale * (icon_to_add.scale or (0.5 * defines.default_icon_size / icon.icon_size))
     if icon_to_add.shift then
       icon.shift = {icon_to_add.shift[1] * scale + shift[1], icon_to_add.shift[2] * scale + shift[2]}
     else
@@ -395,7 +398,8 @@ function util.technology_icon_constant_damage(technology_icon)
       icon = "__core__/graphics/icons/technology/constants/constant-damage.png",
       icon_size = 128,
       scale = 0.5,
-      shift = {50, 50}
+      shift = {50, 50},
+      floating = true
     }
   }
   return icons
@@ -411,7 +415,8 @@ function util.technology_icon_constant_speed(technology_icon)
       icon = "__core__/graphics/icons/technology/constants/constant-speed.png",
       icon_size = 128,
       scale = 0.5,
-      shift = {50, 50}
+      shift = {50, 50},
+      floating = true
     }
   }
   return icons
@@ -427,7 +432,8 @@ function util.technology_icon_constant_movement_speed(technology_icon)
       icon = "__core__/graphics/icons/technology/constants/constant-movement-speed.png",
       icon_size = 128,
       scale = 0.5,
-      shift = {50, 50}
+      shift = {50, 50},
+      floating = true
     }
   }
   return icons
@@ -443,7 +449,8 @@ function util.technology_icon_constant_range(technology_icon)
       icon = "__core__/graphics/icons/technology/constants/constant-range.png",
       icon_size = 128,
       scale = 0.5,
-      shift = {50, 50}
+      shift = {50, 50},
+      floating = true
     }
   }
   return icons
@@ -459,7 +466,8 @@ function util.technology_icon_constant_planet(technology_icon)
       icon = "__core__/graphics/icons/technology/constants/constant-planet.png",
       icon_size = 128,
       scale = 0.5,
-      shift = {50, 50}
+      shift = {50, 50},
+      floating = true
     }
   }
   return icons
@@ -475,7 +483,8 @@ function util.technology_icon_constant_equipment(technology_icon)
       icon = "__core__/graphics/icons/technology/constants/constant-equipment.png",
       icon_size = 128,
       scale = 0.5,
-      shift = {50, 50}
+      shift = {50, 50},
+      floating = true
     }
   }
   return icons
@@ -491,7 +500,8 @@ function util.technology_icon_constant_followers(technology_icon)
       icon = "__core__/graphics/icons/technology/constants/constant-count.png",
       icon_size = 128,
       scale = 0.5,
-      shift = {50, 50}
+      shift = {50, 50},
+      floating = true
     }
   }
   return icons
@@ -507,7 +517,8 @@ function util.technology_icon_constant_capacity(technology_icon)
       icon = "__core__/graphics/icons/technology/constants/constant-capacity.png",
       icon_size = 128,
       scale = 0.5,
-      shift = {50, 50}
+      shift = {50, 50},
+      floating = true
     }
   }
   return icons
@@ -523,7 +534,8 @@ function util.technology_icon_constant_stack_size(technology_icon)
       icon = "__core__/graphics/icons/technology/constants/constant-capacity.png",
       icon_size = 128,
       scale = 0.5,
-      shift = {50, 50}
+      shift = {50, 50},
+      floating = true
     }
   }
   return icons
@@ -539,7 +551,8 @@ function util.technology_icon_constant_productivity(technology_icon)
       icon = "__core__/graphics/icons/technology/constants/constant-mining-productivity.png",
       icon_size = 128,
       scale = 0.5,
-      shift = {50, 50}
+      shift = {50, 50},
+      floating = true
     }
   }
   return icons
@@ -555,7 +568,8 @@ function util.technology_icon_constant_recipe_productivity(technology_icon)
       icon = "__core__/graphics/icons/technology/constants/constant-recipe-productivity.png",
       icon_size = 128,
       scale = 0.5,
-      shift = {50, 50}
+      shift = {50, 50},
+      floating = true
     }
   }
   return icons
@@ -571,7 +585,8 @@ function util.technology_icon_constant_braking_force(technology_icon)
       icon = "__core__/graphics/icons/technology/constants/constant-braking-force.png",
       icon_size = 128,
       scale = 0.5,
-      shift = {50, 50}
+      shift = {50, 50},
+      floating = true
     }
   }
   return icons
@@ -587,7 +602,8 @@ function util.technology_icon_constant_mining(technology_icon)
       icon = "__core__/graphics/icons/technology/constants/constant-mining.png",
       icon_size = 128,
       scale = 0.5,
-      shift = {50, 50}
+      shift = {50, 50},
+      floating = true
     }
   }
   return icons
@@ -805,6 +821,10 @@ util.normalize_recipe_products = function(recipe)
   local products = {}
 
   for _,raw_product in pairs(recipe.results) do
+    if type(raw_product) ~= "table" then
+      error("Recipe "..recipe.name.." has malformed results: it should only contain tables (one per product) but "..type(raw_product).." was found")
+    end
+
     table.insert(products, util.normalize_recipe_product(raw_product))
   end
 
@@ -833,6 +853,27 @@ util.get_recipe_main_product = function(recipe, normalized_products)
   return normalized_products[main_product_index]
 end
 
+local function is_sprite_def(array)
+  return array.icon or array.width and array.height and (array.filename or array.stripes or array.filenames)
+end
+--- Recursively tint all sprite definitions in the given table.
+--- If `tint` is `false`, all tinting will be removed.
+function util.recursive_tint(array, tint)
+  for _, v in pairs(array) do
+    if type(v) == "table" then
+      if is_sprite_def(v) then
+        if tint == false then
+          v.tint = nil
+        else
+          v.tint = tint
+        end
+      end
+      v = util.recursive_tint(v, tint)
+    end
+  end
+  return array
+end
+
 gram = 1
 grams = gram
 kg = 1000*grams
