@@ -253,6 +253,7 @@ data:extend(
     small_area_size = 1.5, -- less than this plays the 'small' sound variants
     medium_area_size = 6.5, -- less than this plays the 'medium' sound variants
     large_area_size = 15, -- less than this plays the 'large' sound variants, otherwise plays the 'huge' sound variants.
+    huge_platform_animation_sound_area = 81, -- 9x9 area - anything larger than this, the engine will speed up the animation so it ends as if it was this size
 
     small_blueprint_area_size = 50, -- less than this plays the 'small' sound variants
     medium_blueprint_area_size = 200, -- less than this plays the 'medium' sound variants
@@ -385,13 +386,17 @@ data:extend(
     -- with decoratives being most demanding on that, using them as heuristic
     entity_renderer_search_box_limits =
     {
-      left = 6, -- to compensate for shadows
-      top = 3,
-      right = 3,
-      bottom = 4 -- to compensate for tall entities like electric poles
+      -- In 1.1 it was left = 6 to compensate for shadows, bottom = 4 to compensate for tall entities like trees and electric poles and top and right 3.
+      -- In 2.0 they all are set to 6 because of robot optimization which makes them move only once per 20 ticks,
+      -- so they "teleport" into the view if they are fast enough (https://forums.factorio.com/124268). This doesn't fix the issue fully,
+      -- it will start to appear if bots have high enough speed.
+      left = 6,
+      top = 6,
+      right = 6,
+      bottom = 6
     },
 
-    light_renderer_search_distance_limit = 22,
+    light_renderer_search_distance_limit = 20,
 
     tree_leaf_distortion_strength_far = { 0.46, 0.47 },
     tree_leaf_distortion_distortion_far = { 7.6, 9.1 },
@@ -480,8 +485,13 @@ data:extend(
 
     select_group_row_count = 6,
     select_slot_row_count = 10,
+    logistic_slots_per_row = 10,
+    crafting_queue_slots_per_row = 10,
+    blueprint_big_slots_per_row = 6,
+    blueprint_small_slots_per_row = 10,
     inventory_width = 10,
     module_inventory_width = 10,
+    trash_inventory_width = 10,
     tooltip_monitor_edge_border = 10,
     flying_text_ttl = 80,
 
@@ -515,6 +525,9 @@ data:extend(
     space_platform_starfield_movement_vector = { 0, -0.02 },
     space_platform_max_size = {{-1000000, -200}, {1000000, 1000000}},
     space_platform_dump_cooldown = 30 * second,
+    space_platform_manual_dump_cooldown = 2 * second,
+    space_platform_max_relative_speed_deviation_for_asteroid_chunks_update = 1/second,
+    space_platform_asteroid_chunk_trajectory_updates_per_tick = 1,
 
     default_item_weight = 100,
     rocket_lift_weight = 1000000, -- 1 000 kg
@@ -537,6 +550,8 @@ data:extend(
     landing_area_clear_zone_radius = 8,
     landing_area_max_radius = 16,
 
+    landing_squash_immunity = 5 * second,
+
     ejected_item_lifetime = 25 * second,
     ejected_item_speed = 0.005,
     ejected_item_direction_variation = 0.05,
@@ -593,5 +608,13 @@ data:extend(
     starmap_orbit_disabled_color = {0.25, 0.25, 0.25},
 
     time_to_show_full_health_bar = 5,
+
+    capture_water_mask_at_layer = 200, -- need to capture water close to layer in which decals that need to be masked are rendered,
+                                      -- otherwise we risk that some tiles that are supposed to be under the decals and not mask them
+                                      -- would not be rendered yet and therefore would have value 0 in water mask
+
+    logistic_robots_use_busy_robots_queue = true,
+    construction_robots_use_busy_robots_queue = true,
+    quality_selector_dropdown_threshold = 6,
   }
 })
