@@ -1,5 +1,6 @@
 local hit_effects = require ("__base__.prototypes.entity.hit-effects")
-local sounds = require ("__base__.prototypes.entity.sounds")
+local base_sounds = require ("__base__.prototypes.entity.sounds")
+local base_tile_sounds = require ("__base__.prototypes.tile.tile-sounds")
 local decorative_trigger_effects = require("__base__.prototypes.decorative.decorative-trigger-effects")
 local simulations = require("__space-age__.prototypes.factoriopedia-simulations")
 
@@ -10,7 +11,7 @@ local function fulgora_ruin(args)
   ruin.flags = {"placeable-neutral", "placeable-off-grid"}
   ruin.icon = "__space-age__/graphics/icons/"..args.name..".png"
   ruin.subgroup = "grass"
-  ruin.order = "b[decorative]-l[rock]-j[ruin]-" .. (args.order or "a")
+  ruin.order = "b[decorative]-l[rock]-d[fulgora]-e[ruin]-" .. (args.order or "a")
   ruin.collision_box = args.collision_box or {{-1,-1}, {1,1}}
   ruin.selection_box = args.selection_box or {{ruin.collision_box[1][1]-0.2, ruin.collision_box[1][2]-0.2}, {ruin.collision_box[2][1]+0.2, ruin.collision_box[2][2]+0.2}}
   ruin.damaged_trigger_effect = hit_effects.rock()
@@ -58,7 +59,7 @@ data:extend(
     order = "a[fulgora]-b[decorative]",
     collision_box = {{-0.45, -0.45}, {0.45, 0.45}},
     collision_mask = {layers={object=true}, colliding_with_tiles_only=true},
-    walking_sound = sounds.pebble,
+    walking_sound = base_tile_sounds.walking.pebble,
     pictures = util.spritesheets_to_pictures({{path = "__space-age__/graphics/decorative/fulgoran-ruin/fulgoran-ruin-tiny", frame_count = 35,     scale = 0.3}}),
     autoplace = {
       order = "a[ruin]-i[tiny]",
@@ -73,7 +74,7 @@ data:extend(
   },
   fulgora_ruin({
     name = "fulgoran-ruin-small",
-    order = "b[decorative]-l[rock]-j[ruin]-b[small]",
+    order = "b[decorative]-l[rock]-d[fulgora]-e[ruin]-b[small]",
     collision_box = {{-0.77, -0.68}, {0.77, 0.68}},
     map_color = {110, 110, 110, 128},
     pictures = {
@@ -89,7 +90,7 @@ data:extend(
   }),
   fulgora_ruin({
     name = "fulgoran-ruin-medium",
-    order = "b[decorative]-l[rock]-j[ruin]-c[medium]",
+    order = "b[decorative]-l[rock]-d[fulgora]-e[ruin]-c[medium]",
     collision_box = {{-1.21, -0.86}, {1.21, 0.86}},
     map_color = {115, 115, 115, 128},
     pictures = {
@@ -105,7 +106,7 @@ data:extend(
   }),
   fulgora_ruin({
     name = "fulgoran-ruin-stonehenge",
-    order = "b[decorative]-l[rock]-j[ruin]-d[stonehenge]",
+    order = "b[decorative]-l[rock]-d[fulgora]-e[ruin]-d[stonehenge]",
     collision_box = {{-1.56, -1.32}, {1.56, 1.32}},
     map_color = {120, 120, 120, 128},
     frame_count = 8,
@@ -116,7 +117,7 @@ data:extend(
   }),
   fulgora_ruin({
     name = "fulgoran-ruin-big",
-    order = "b[decorative]-l[rock]-j[ruin]-e[big]",
+    order = "b[decorative]-l[rock]-d[fulgora]-e[ruin]-e[big]",
     collision_box = {{-1.77, -1.49}, {1.77, 1.49}},
     map_color = {120, 120, 120, 128},
     frame_count = 7,
@@ -127,7 +128,7 @@ data:extend(
   }),
   fulgora_ruin({
     name = "fulgoran-ruin-huge",
-    order = "b[decorative]-l[rock]-j[ruin]-f[huge]",
+    order = "b[decorative]-l[rock]-d[fulgora]-e[ruin]-f[huge]",
     collision_box = {{-2.78, -2.33}, {2.78, 2.33}},
     map_color = {125, 125, 125, 128},
     pictures = {
@@ -142,7 +143,7 @@ data:extend(
   }),
   fulgora_ruin({
     name = "fulgoran-ruin-colossal",
-    order = "b[decorative]-l[rock]-j[ruin]-f[colossal]",
+    order = "b[decorative]-l[rock]-d[fulgora]-e[ruin]-f[colossal]",
     frame_count = 3,
     dice_y = 2,
     collision_box = {{-3.47, -2.66}, {3.47, 2.66}},
@@ -154,7 +155,7 @@ data:extend(
   }),
   fulgora_ruin({
     name = "fulgoran-ruin-vault",
-    order = "b[decorative]-l[rock]-j[ruin]-g[vault]",
+    order = "b[decorative]-l[rock]-d[fulgora]-e[ruin]-g[vault]",
     frame_count = 1,
     dice_y = 2,
     collision_box = {{-6.88, -4}, {6.88, 4}},
@@ -185,7 +186,7 @@ data:extend(
       transfer_entity_health_to_products = false
     },
     subgroup = "grass",
-    order = "b[decorative]-l[rock]-j[ruin]-h[attractor]",
+    order = "b[decorative]-l[rock]-d[fulgora]-d[fulgoran-ruin-attractor]",
     factoriopedia_simulation = simulations.factoriopedia_fulgoran_ruin_attractor,
     autoplace = {
       order = "a[ruin]-b[attractor]",
@@ -212,8 +213,8 @@ data:extend(
     lightning_strike_offset = {0.5, -4.0},
     damaged_trigger_effect = hit_effects.entity({{-0.2, -2.2},{0.2, 0.2}}),
     drawing_box_vertical_extension = 4,
-    open_sound = sounds.electric_network_open,
-    close_sound = sounds.electric_network_close,
+    open_sound = base_sounds.electric_network_open,
+    close_sound = base_sounds.electric_network_close,
     stateless_visualisation =
     {
       period = 0,
@@ -261,7 +262,7 @@ data:extend(
     order = "a[fulgora]-b[decorative]",
     collision_box = {{-0.5, -0.5}, {0.5, 0.5}},
     collision_mask = {layers={water_tile=true}, colliding_with_tiles_only=true},
-    walking_sound = sounds.grass,
+    walking_sound = base_tile_sounds.walking.grass,
     autoplace = {
       probability_expression = "min(0.1, fulgora_natural_mask * max(0, fulgora_scrap_medium + fulgora_rock - fulgora_basis_oil - 2.5))",
     },
@@ -273,12 +274,12 @@ data:extend(
     order = "a[fulgora]-b[decorative]",
     collision_box = {{-0.5, -0.5}, {0.5, 0.5}},
     collision_mask = {layers={water_tile=true}, colliding_with_tiles_only=true},
-    walking_sound = sounds.grass,
+    walking_sound = base_tile_sounds.walking.big_bush,
     autoplace = {
       placement_density = 2,
       probability_expression = "min(0.1, fulgora_natural_mask * max(0, fulgora_scrap_medium - fulgora_rock - 0.75))",
     },
-    pictures = util.spritesheets_to_pictures({{path = "__space-age__/graphics/decorative/urchin-cactus/urchin-cactus", frame_count = 3}})
+    pictures = util.spritesheets_to_pictures({{path = "__space-age__/graphics/decorative/urchin-cactus/urchin-cactus", frame_count = 10}})
   },
   {
     type = "simple-entity",
@@ -286,7 +287,7 @@ data:extend(
     flags = {"placeable-neutral", "placeable-off-grid"},
     icon = "__space-age__/graphics/icons/fulgurite-small.png",
     subgroup = "grass",
-    order = "b[decorative]-l[rock]-i[fulgurite]",
+    order = "b[decorative]-l[rock]-d[fulgora]-b[fulgurite-small]",
     collision_box = {{-0.5, -0.5}, {0.5, 0.5}},
     selection_box = {{-0.5, -0.5}, {0.5, 0.5}},
     drawing_box_vertical_extension = 1,
@@ -304,7 +305,7 @@ data:extend(
     },
     map_color = {194, 41, 116, 64},
     count_as_rock_for_filtered_deconstruction = true,
-    mined_sound = { filename = "__base__/sound/deconstruct-bricks.ogg" },
+    mined_sound = base_sounds.deconstruct_bricks(1.0),
     impact_category = "stone",
     render_layer = "object",
     max_health = 70,
@@ -325,7 +326,7 @@ data:extend(
     flags = {"placeable-neutral", "placeable-off-grid"},
     icon = "__space-age__/graphics/icons/fulgurite.png",
     subgroup = "grass",
-    order = "b[decorative]-l[rock]-i[fulgurite]",
+    order = "b[decorative]-l[rock]-d[fulgora]-c[fulgurite]",
     collision_box = {{-1.0, -0.9}, {1.0, 0.9}},
     selection_box = {{-1.2, -1.1}, {1.2, 1.1}},
     drawing_box_vertical_extension = 1,
@@ -343,7 +344,7 @@ data:extend(
     },
     map_color = {194, 41, 116, 64},
     count_as_rock_for_filtered_deconstruction = true,
-    mined_sound = { filename = "__base__/sound/deconstruct-bricks.ogg" },
+    mined_sound = base_sounds.deconstruct_bricks(1.0),
     impact_category = "stone",
     render_layer = "object",
     max_health = 200,
@@ -456,7 +457,7 @@ for name, original in pairs(rocks) do
   local rock = table.deepcopy(original)
   rock.name = name
   if name == "big-fulgora-rock" then
-    rock.order = "b[decorative]-l[rock]-j[ruin]-a[" .. name .. "]"
+    rock.order = "b[decorative]-l[rock]-d[fulgora]-a[" .. name .. "]"
     rock.icon = "__space-age__/graphics/icons/" .. name .. ".png"
   end
   for j, picture in pairs(rock.pictures) do
