@@ -174,7 +174,7 @@ local function fluids_front(with_fluid)
 end
 
 local function graphical_set(with_fluid)
-  return
+  local ret =
   {
     drilling_vertical_movement_duration = 15 / animation_speed,
     shift_animation_waypoint_stop_duration = drilling_frames / animation_speed,
@@ -225,318 +225,328 @@ local function graphical_set(with_fluid)
       east =  waypoints_stops({-0.85, 0},{0.2, 0}),
       south = waypoints_stops({0, -0.9},{0, 0.3}),
       west =  waypoints_stops({-0.2, 0},{0.85, 0})
-    },
-
-    working_visualisations =
-    {
-      -- scortchmark
-      {
-        always_draw = true,
-        mining_drill_scorch_mark = true,
-        scorch_mark_fade_in_frames = 30,
-        scorch_mark_fade_out_duration = 300,
-        scorch_mark_lifetime = 600,
-        animation = bmd_sprite_load("drill-scorchmark", {}),
-        north_position = { 0, 0.15},
-        east_position = { 0, 0 },
-        south_position = { 0, 0.15},
-        west_position = { 0, 0 }
-      },
-      -- drill animation
-      {
-        name = "drill-animation",
-        animated_shift = true,
-        always_draw = true,
-        animation ={
-          layers =
-          {
-            bmd_sprite_load("drill",
-            {
-              frame_sequence = drill_sequence,
-              frame_count = 36,
-            }),
-            bmd_sprite_load("drill-shadow",
-            {
-              frame_sequence = drill_sequence,
-              frame_count = 36,
-              draw_as_shadow = true,
-            })
-          }
-        },
-        north_position = { 0, 0.15},
-        east_position = { 0, 0 },
-        south_position = { 0, 0.15},
-        west_position = { 0, 0 }
-      },
-
-      -- dust animation
-      {
-        --constant_speed = true,
-        synced_fadeout = true,
-        align_to_waypoint = true,
-        --apply_tint = "resource-color",
-        animation = bmd_sprite_load("drill-dust", {frame_count = 24}),
-        north_position = { 0, 0.15},
-        east_position = { 0, 0 },
-        south_position = { 0, 0.15},
-        west_position = { 0, 0 }
-      },
-      -- dust animation
-      {
-        --constant_speed = true,
-        synced_fadeout = true,
-        align_to_waypoint = true,
-        apply_tint = "resource-color",
-        animation = bmd_sprite_load("drill-dust-tint", {frame_count = 24}),
-        north_position = { 0, 0.15},
-        east_position = { 0, 0 },
-        south_position = { 0, 0.15},
-        west_position = { 0, 0 }
-      },
-
-      {
-        always_draw = true,
-        north_animation = bmd_sprite_load("N-still", { dice = 2 }),
-        east_animation = bmd_sprite_load("E-still-reel", {}),
-        south_animation = bmd_sprite_load("S-still", { dice_x = 2 }),
-        west_animation = bmd_sprite_load("W-still-reel", {}),
-      },
-
-      -- wheels transition
-      {
-        animated_shift = true,
-        always_draw = true,
-        enabled_in_animated_shift_during_waypoint_stop = false,
-        enabled_in_animated_shift_during_transition = true,
-        frame_based_on_shift_animation_progress = true,
-
-        north_animation = bmd_sprite_load("N-wheels", {animation_speed = 0.2, frame_count = 3, dice_x = 2 }),
-        east_animation = bmd_sprite_load("E-wheels", {animation_speed = 0.2, frame_count = 3, dice_y = 2 }),
-        south_animation = bmd_sprite_load("S-wheels", {animation_speed = 0.2, frame_count = 3, dice_x = 2 }),
-        west_animation = bmd_sprite_load("W-wheels", {animation_speed = 0.2, frame_count = 3, dice_y = 2 }),
-      },
-
-      -- wheels waypoint stop
-      {
-        animated_shift = true,
-        always_draw = true,
-        enabled_in_animated_shift_during_waypoint_stop = true,
-        enabled_in_animated_shift_during_transition = false,
-        frame_based_on_shift_animation_progress = true,
-
-        north_animation = bmd_sprite_load("N-wheels", {animation_speed = 0.2, frame_count = 3, dice_x = 2 }),
-        east_animation = bmd_sprite_load("E-wheels", {animation_speed = 0.2, frame_count = 3, dice_y = 2 }),
-        south_animation = bmd_sprite_load("S-wheels", {animation_speed = 0.2, frame_count = 3, dice_x = 2 }),
-        west_animation = bmd_sprite_load("W-wheels", {animation_speed = 0.2, frame_count = 3, dice_y = 2 }),
-      },
-
-      -- output
-      {
-        animated_shift = false,
-        always_draw = true,
-
-        north_animation= bmd_sprite_load("N-output", {frame_count = 5}),
-        east_animation = bmd_sprite_load("E-output", {frame_count = 5}),
-        south_animation = bmd_sprite_load("S-output", {frame_count = 5}),
-        west_animation = bmd_sprite_load("W-output", {frame_count = 5}),
-      },
-
-      fluids(with_fluid),
-
-      -- drill support animation
-      {
-        animated_shift = true,
-        always_draw = true,
-        north_animation = { layers =
-        {
-          bmd_sprite_load("N-support",
-          {
-            frame_sequence = support_sequence,
-            frame_count = 6,
-            dice_x = 3,
-          }),
-          bmd_sprite_load("N-support-shadow",
-          {
-            draw_as_shadow = true,
-            repeat_count = drilling_frames,
-            frame_count = 1,
-          })
-        }},
-        east_animation = { layers =
-        {
-          bmd_sprite_load("E-support",
-          {
-            frame_sequence = support_sequence,
-            frame_count = 6,
-          }),
-          bmd_sprite_load("E-support-shadow",
-          {
-            draw_as_shadow = true,
-            repeat_count = drilling_frames,
-            frame_count = 1,
-          })
-        }},
-        south_animation = { layers =
-        {
-          bmd_sprite_load("S-support",
-          {
-            frame_sequence = support_sequence,
-            frame_count = 6,
-            dice_x = 3,
-          }),
-          bmd_sprite_load("S-support-shadow",
-          {
-            draw_as_shadow = true,
-            repeat_count = drilling_frames,
-            frame_count = 1,
-          })
-        }},
-        west_animation = { layers =
-        {
-          bmd_sprite_load("W-support",
-          {
-            frame_sequence = support_sequence,
-            frame_count = 6,
-          }),
-          bmd_sprite_load("W-support-shadow",
-          {
-            draw_as_shadow = true,
-            repeat_count = drilling_frames,
-            frame_count = 1,
-          })
-        }},
-      },
-
-      -- front frame
-      {
-        always_draw = true,
-        north_animation = bmd_sprite_load("N-still-front",{ dice = 2 }),
-        east_animation = bmd_sprite_load("E-still-front",{ dice = 2 }),
-        south_animation = bmd_sprite_load("S-still-front",{ dice = 2 }),
-        west_animation = bmd_sprite_load("W-still-front",{ dice = 2 }),
-      },
-
-      -- output-particles
-      {
-        synced_fadeout = true,
-        apply_tint = "resource-color",
-        always_draw = true,
-        north_animation = bmd_sprite_load("N-output-particles", {frame_count = 24}),
-        east_animation = bmd_sprite_load("E-output-particles", {frame_count = 24}),
-        south_animation = bmd_sprite_load("S-output-particles", {frame_count = 24}),
-        west_animation = bmd_sprite_load("W-output-particles", {frame_count = 24}),
-      },
-
-      fluids_front(with_fluid),
-
-      -- LEDs
-      {
-        apply_tint = "status",
-        always_draw = true,
-        north_animation = bmd_sprite_load("N-lamp", { blend_mode = "additive", draw_as_glow = true }),
-        east_animation = bmd_sprite_load("E-lamp", { blend_mode = "additive", draw_as_glow = true }),
-        south_animation = bmd_sprite_load("S-lamp", { blend_mode = "additive", draw_as_glow = true }),
-        west_animation = bmd_sprite_load("W-lamp", { blend_mode = "additive", draw_as_glow = true })
-      },
-
-      -- drill top nozzle animation
-      {
-        always_draw = true,
-        north_animation = bmd_sprite_load("N-top-nozzle",
-        {
-          frame_sequence = nozzle_frame_sequence,
-          frame_count = 19,
-        }),
-        east_animation = bmd_sprite_load("E-top-nozzle",
-        {
-          frame_sequence = nozzle_frame_sequence,
-          frame_count = 19,
-        }),
-        south_animation = bmd_sprite_load("S-top-nozzle",
-        {
-          frame_sequence = nozzle_frame_sequence,
-          frame_count = 19,
-        }),
-        west_animation = bmd_sprite_load("W-top-nozzle",
-        {
-          frame_sequence = nozzle_frame_sequence,
-          frame_count = 19,
-        }),
-      },
-          -- drill top animation
-      {
-        animated_shift = true,
-        always_draw = true,
-        north_animation = { layers =
-        {
-          bmd_sprite_load("N-top",
-          {
-            frame_sequence = top_sequence,
-            frame_count = 18,
-          }),
-          bmd_sprite_load("N-top-shadow",
-          {
-            frame_sequence = top_sequence,
-            frame_count = 18,
-            draw_as_shadow = true
-          })
-        }},
-        east_animation = { layers =
-        {
-          bmd_sprite_load("E-top",
-          {
-            frame_sequence = top_sequence,
-            frame_count = 18,
-          }),
-          bmd_sprite_load("E-top-shadow",
-          {
-            frame_sequence = top_sequence,
-            frame_count = 18,
-            draw_as_shadow = true
-          })
-        }},
-        south_animation = { layers =
-        {
-          bmd_sprite_load("S-top",
-          {
-            frame_sequence = top_sequence,
-            frame_count = 18,
-          }),
-          bmd_sprite_load("S-top-shadow",
-          {
-            frame_sequence = top_sequence,
-            frame_count = 18,
-            draw_as_shadow = true
-          })
-        }},
-        west_animation = { layers =
-        {
-          bmd_sprite_load("W-top",
-          {
-            frame_sequence = top_sequence,
-            frame_count = 18,
-          }),
-          bmd_sprite_load("W-top-shadow",
-          {
-            frame_sequence = top_sequence,
-            frame_count = 18,
-            draw_as_shadow = true
-          })
-        }}
-      },
-
-        -- LEDs glow
-      {
-        always_draw = true,
-        apply_tint = "status",
-        light = { intensity = 0.25, size = 4.0, minimum_darkness = 0.00 },
-        north_position = {-1.0, -2.65},
-        east_position =  { 2.1, -1.20},
-        south_position = {-1.0,  0.32},
-        west_position =  {-2.1, -1.20}
-      }
     }
   }
+
+  local working_vis =
+  {
+    -- scortchmark
+    {
+      always_draw = true,
+      mining_drill_scorch_mark = true,
+      scorch_mark_fade_in_frames = 30,
+      scorch_mark_fade_out_duration = 300,
+      scorch_mark_lifetime = 600,
+      animation = bmd_sprite_load("drill-scorchmark", {}),
+      north_position = { 0, 0.15},
+      east_position = { 0, 0 },
+      south_position = { 0, 0.15},
+      west_position = { 0, 0 }
+    },
+    -- drill animation
+    {
+      name = "drill-animation",
+      animated_shift = true,
+      always_draw = true,
+      animation ={
+        layers =
+        {
+          bmd_sprite_load("drill",
+          {
+            frame_sequence = drill_sequence,
+            frame_count = 36,
+          }),
+          bmd_sprite_load("drill-shadow",
+          {
+            frame_sequence = drill_sequence,
+            frame_count = 36,
+            draw_as_shadow = true,
+          })
+        }
+      },
+      north_position = { 0, 0.15},
+      east_position = { 0, 0 },
+      south_position = { 0, 0.15},
+      west_position = { 0, 0 }
+    },
+
+    -- dust animation
+    {
+      --constant_speed = true,
+      synced_fadeout = true,
+      align_to_waypoint = true,
+      --apply_tint = "resource-color",
+      animation = bmd_sprite_load("drill-dust", {frame_count = 24}),
+      north_position = { 0, 0.15},
+      east_position = { 0, 0 },
+      south_position = { 0, 0.15},
+      west_position = { 0, 0 }
+    },
+    -- dust animation
+    {
+      --constant_speed = true,
+      synced_fadeout = true,
+      align_to_waypoint = true,
+      apply_tint = "resource-color",
+      animation = bmd_sprite_load("drill-dust-tint", {frame_count = 24}),
+      north_position = { 0, 0.15},
+      east_position = { 0, 0 },
+      south_position = { 0, 0.15},
+      west_position = { 0, 0 }
+    },
+
+    {
+      always_draw = true,
+      north_animation = bmd_sprite_load("N-still", { dice = 2 }),
+      east_animation = bmd_sprite_load("E-still-reel", {}),
+      south_animation = bmd_sprite_load("S-still", { dice_x = 2 }),
+      west_animation = bmd_sprite_load("W-still-reel", {}),
+    },
+
+    -- wheels transition
+    {
+      animated_shift = true,
+      always_draw = true,
+      enabled_in_animated_shift_during_waypoint_stop = false,
+      enabled_in_animated_shift_during_transition = true,
+      frame_based_on_shift_animation_progress = true,
+
+      north_animation = bmd_sprite_load("N-wheels", {animation_speed = 0.2, frame_count = 3, dice_x = 2 }),
+      east_animation = bmd_sprite_load("E-wheels", {animation_speed = 0.2, frame_count = 3, dice_y = 2 }),
+      south_animation = bmd_sprite_load("S-wheels", {animation_speed = 0.2, frame_count = 3, dice_x = 2 }),
+      west_animation = bmd_sprite_load("W-wheels", {animation_speed = 0.2, frame_count = 3, dice_y = 2 }),
+    },
+
+    -- wheels waypoint stop
+    {
+      animated_shift = true,
+      always_draw = true,
+      enabled_in_animated_shift_during_waypoint_stop = true,
+      enabled_in_animated_shift_during_transition = false,
+      frame_based_on_shift_animation_progress = true,
+
+      north_animation = bmd_sprite_load("N-wheels", {animation_speed = 0.2, frame_count = 3, dice_x = 2 }),
+      east_animation = bmd_sprite_load("E-wheels", {animation_speed = 0.2, frame_count = 3, dice_y = 2 }),
+      south_animation = bmd_sprite_load("S-wheels", {animation_speed = 0.2, frame_count = 3, dice_x = 2 }),
+      west_animation = bmd_sprite_load("W-wheels", {animation_speed = 0.2, frame_count = 3, dice_y = 2 }),
+    },
+
+    -- output
+    {
+      animated_shift = false,
+      always_draw = true,
+
+      north_animation= bmd_sprite_load("N-output", {frame_count = 5}),
+      east_animation = bmd_sprite_load("E-output", {frame_count = 5}),
+      south_animation = bmd_sprite_load("S-output", {frame_count = 5}),
+      west_animation = bmd_sprite_load("W-output", {frame_count = 5}),
+    }
+  }
+
+  if with_fluid then
+    working_vis[#working_vis+1] = fluids(with_fluid)
+  end
+
+  -- drill support animation
+  working_vis[#working_vis+1] =
+  {
+    animated_shift = true,
+    always_draw = true,
+    north_animation = { layers =
+    {
+      bmd_sprite_load("N-support",
+      {
+        frame_sequence = support_sequence,
+        frame_count = 6,
+        dice_x = 3,
+      }),
+      bmd_sprite_load("N-support-shadow",
+      {
+        draw_as_shadow = true,
+        repeat_count = drilling_frames,
+        frame_count = 1,
+      })
+    }},
+    east_animation = { layers =
+    {
+      bmd_sprite_load("E-support",
+      {
+        frame_sequence = support_sequence,
+        frame_count = 6,
+      }),
+      bmd_sprite_load("E-support-shadow",
+      {
+        draw_as_shadow = true,
+        repeat_count = drilling_frames,
+        frame_count = 1,
+      })
+    }},
+    south_animation = { layers =
+    {
+      bmd_sprite_load("S-support",
+      {
+        frame_sequence = support_sequence,
+        frame_count = 6,
+        dice_x = 3,
+      }),
+      bmd_sprite_load("S-support-shadow",
+      {
+        draw_as_shadow = true,
+        repeat_count = drilling_frames,
+        frame_count = 1,
+      })
+    }},
+    west_animation = { layers =
+    {
+      bmd_sprite_load("W-support",
+      {
+        frame_sequence = support_sequence,
+        frame_count = 6,
+      }),
+      bmd_sprite_load("W-support-shadow",
+      {
+        draw_as_shadow = true,
+        repeat_count = drilling_frames,
+        frame_count = 1,
+      })
+    }},
+  }
+  -- front frame
+  working_vis[#working_vis+1] =
+  {
+    always_draw = true,
+    north_animation = bmd_sprite_load("N-still-front",{ dice = 2 }),
+    east_animation = bmd_sprite_load("E-still-front",{ dice = 2 }),
+    south_animation = bmd_sprite_load("S-still-front",{ dice = 2 }),
+    west_animation = bmd_sprite_load("W-still-front",{ dice = 2 }),
+  }
+  -- output-particles
+  working_vis[#working_vis+1] =
+  {
+    synced_fadeout = true,
+    apply_tint = "resource-color",
+    always_draw = true,
+    north_animation = bmd_sprite_load("N-output-particles", {frame_count = 24}),
+    east_animation = bmd_sprite_load("E-output-particles", {frame_count = 24}),
+    south_animation = bmd_sprite_load("S-output-particles", {frame_count = 24}),
+    west_animation = bmd_sprite_load("W-output-particles", {frame_count = 24}),
+  }
+
+  if with_fluid then
+    working_vis[#working_vis+1] = fluids_front(with_fluid)
+  end
+
+  -- LEDs
+  working_vis[#working_vis+1] =
+  {
+    apply_tint = "status",
+    always_draw = true,
+    north_animation = bmd_sprite_load("N-lamp", { blend_mode = "additive", draw_as_glow = true }),
+    east_animation = bmd_sprite_load("E-lamp", { blend_mode = "additive", draw_as_glow = true }),
+    south_animation = bmd_sprite_load("S-lamp", { blend_mode = "additive", draw_as_glow = true }),
+    west_animation = bmd_sprite_load("W-lamp", { blend_mode = "additive", draw_as_glow = true })
+  }
+  -- drill top nozzle animation
+  working_vis[#working_vis+1] =
+  {
+    always_draw = true,
+    north_animation = bmd_sprite_load("N-top-nozzle",
+    {
+      frame_sequence = nozzle_frame_sequence,
+      frame_count = 19,
+    }),
+    east_animation = bmd_sprite_load("E-top-nozzle",
+    {
+      frame_sequence = nozzle_frame_sequence,
+      frame_count = 19,
+    }),
+    south_animation = bmd_sprite_load("S-top-nozzle",
+    {
+      frame_sequence = nozzle_frame_sequence,
+      frame_count = 19,
+    }),
+    west_animation = bmd_sprite_load("W-top-nozzle",
+    {
+      frame_sequence = nozzle_frame_sequence,
+      frame_count = 19,
+    }),
+  }
+  -- drill top animation
+  working_vis[#working_vis+1] =
+  {
+    animated_shift = true,
+    always_draw = true,
+    north_animation = { layers =
+    {
+      bmd_sprite_load("N-top",
+      {
+        frame_sequence = top_sequence,
+        frame_count = 18,
+      }),
+      bmd_sprite_load("N-top-shadow",
+      {
+        frame_sequence = top_sequence,
+        frame_count = 18,
+        draw_as_shadow = true
+      })
+    }},
+    east_animation = { layers =
+    {
+      bmd_sprite_load("E-top",
+      {
+        frame_sequence = top_sequence,
+        frame_count = 18,
+      }),
+      bmd_sprite_load("E-top-shadow",
+      {
+        frame_sequence = top_sequence,
+        frame_count = 18,
+        draw_as_shadow = true
+      })
+    }},
+    south_animation = { layers =
+    {
+      bmd_sprite_load("S-top",
+      {
+        frame_sequence = top_sequence,
+        frame_count = 18,
+      }),
+      bmd_sprite_load("S-top-shadow",
+      {
+        frame_sequence = top_sequence,
+        frame_count = 18,
+        draw_as_shadow = true
+      })
+    }},
+    west_animation = { layers =
+    {
+      bmd_sprite_load("W-top",
+      {
+        frame_sequence = top_sequence,
+        frame_count = 18,
+      }),
+      bmd_sprite_load("W-top-shadow",
+      {
+        frame_sequence = top_sequence,
+        frame_count = 18,
+        draw_as_shadow = true
+      })
+    }}
+  }
+  -- LEDs glow
+  working_vis[#working_vis+1] =
+  {
+    always_draw = true,
+    apply_tint = "status",
+    light = { intensity = 0.25, size = 4.0, minimum_darkness = 0.00 },
+    north_position = {-1.0, -2.65},
+    east_position =  { 2.1, -1.20},
+    south_position = {-1.0,  0.32},
+    west_position =  {-2.1, -1.20}
+  }
+
+  ret.working_visualisations = working_vis
+  return ret
 end
 
 
@@ -583,13 +593,12 @@ data:extend(
       sound_accents =
       {
         {
-          sound = {filename = "__space-age__/sound/entity/big-mining-drill/big-mining-drill-start.ogg", volume = 0.75},
+          sound = {filename = "__space-age__/sound/entity/big-mining-drill/big-mining-drill-start.ogg", volume = 0.75, audible_distance_modifier = 0.3},
           play_for_working_visualisation = "drill-animation",
           frame = 8,
-          audible_distance_modifier = 0.3
         }
       },
-      max_sounds_per_type = 1
+      max_sounds_per_prototype = 1
     },
     moving_sound =
     {
