@@ -297,7 +297,6 @@ data:extend(
     icon = "__space-age__/graphics/icons/railgun-turret.png",
     flags = {"placeable-player", "player-creation", "building-direction-8-way"},
     minable = {mining_time = 0.5, result = "railgun-turret"},
-    fast_replaceable_group = "ammo-turret",
     max_health = 4000,
     corpse = "railgun-turret-remnants",
     dying_explosion = "gun-turret-explosion",
@@ -332,8 +331,8 @@ data:extend(
     can_retarget_while_starting_attack = true,
     circuit_connector = circuit_connector_definitions["railgun-turret"],
     circuit_wire_max_distance = default_circuit_wire_max_distance,
-    open_sound = {filename = "__base__/sound/open-close/turret-open.ogg", volume = 0.6},
-    close_sound = {filename = "__base__/sound/open-close/turret-close.ogg", volume = 0.6},
+    open_sound = sounds.turret_open,
+    close_sound = sounds.turret_close,
     graphics_set =
     {
       base_visualisation =
@@ -377,7 +376,7 @@ data:extend(
       type = "projectile",
       ammo_category = "railgun",
       health_penalty = -1,
-      cooldown = 120,
+      cooldown = 170,
       projectile_creation_distance = 3.6,
       projectile_center = {0, 0},
       apply_projection_to_projectile_creation_position = false,
@@ -395,7 +394,8 @@ data:extend(
       min_range = 3.5,
       range = 40,
       turn_range = 0.20,
-      sound = space_age_sounds.railgun_turret_gunshot
+      sound = space_age_sounds.railgun_turret_gunshot,
+      true_collinear_ejection = true
     },
 
     call_for_help_radius = 40,
@@ -421,7 +421,6 @@ data:extend(
     icon = "__space-age__/graphics/icons/rocket-turret.png",
     flags = {"placeable-player", "player-creation"},
     minable = {mining_time = 0.5, result = "rocket-turret"},
-    fast_replaceable_group = "ammo-turret",
     max_health = 400,
     corpse = "rocket-turret-remnants",
     dying_explosion = "gun-turret-explosion",
@@ -463,8 +462,8 @@ data:extend(
     alert_when_attacking = true,
     circuit_connector = circuit_connector_definitions["rocket-turret"],
     circuit_wire_max_distance = default_circuit_wire_max_distance,
-    open_sound = {filename = "__base__/sound/open-close/turret-open.ogg", volume = 0.6},
-    close_sound = {filename = "__base__/sound/open-close/turret-close.ogg", volume = 0.6},
+    open_sound = sounds.turret_open,
+    close_sound = sounds.turret_close,
     folded_animation = rocket_turret_rising({}),
     preparing_animation = rocket_turret_rising({}),
     prepared_animation = rocket_turret_attack({}),
@@ -568,6 +567,8 @@ data:extend(
     ending_attack_speed = 1 / (30 + 1), -- Must be clocked to the beam duration so the face light turns off at the right time
     circuit_connector = circuit_connector_definitions["tesla-turret"], -- TODO: generate points for tesla-turret
     circuit_wire_max_distance = default_circuit_wire_max_distance,
+    open_sound = sounds.turret_open,
+    close_sound = sounds.turret_close,
     working_sound =
     {
       sound = {filename = "__space-age__/sound/entity/tesla-turret/tesla-turret-base.ogg", volume = 0.3},
