@@ -130,7 +130,7 @@ data:extend(
   {
     type = "tool",
     name = "promethium-science-pack",
-    --localised_description = {"item-description.science-pack"},
+    localised_description = {"item-description.science-pack"},
     icon = "__space-age__/graphics/icons/promethium-science-pack.png",
     subgroup = "science-pack",
     color_hint = { text = "I" },
@@ -252,8 +252,8 @@ data:extend(
     moving_sound = sound_variations("__space-age__/sound/entity/mech-armor/mech-armor-moves", 10, 0.4),
     collision_box = {{-0.25, -0.25}, {0.25, 0.25}},
     drawing_box = {{-0.4, -2}, {0.4, 0}},
-    open_sound = {filename =  "__base__/sound/armor-open.ogg", volume = 1},
-    close_sound = {filename = "__base__/sound/armor-close.ogg", volume = 1},
+    open_sound = sounds.armor_open,
+    close_sound = sounds.armor_close,
     weight = 1*tons
   },
   {
@@ -300,7 +300,7 @@ data:extend(
   {
     type = "space-platform-starter-pack",
     name = "space-platform-starter-pack",
-    icon = "__space-age__/graphics/icons/space-platform-hub.png",
+    icon = "__space-age__/graphics/icons/space-platform-starter-pack.png",
     subgroup = "space-rocket",
     order = "b[space-platform-starter-pack]",
     inventory_move_sound = item_sounds.mechanical_large_inventory_move,
@@ -698,7 +698,7 @@ data:extend(
       { size = 64, filename = "__space-age__/graphics/icons/copper-bacteria-3.png", scale = 0.5, mipmap_count = 4 },
     },
     subgroup = "agriculture-processes",
-    order = "b[agriculture]-d[copper-bacteria]",
+    order = "b[agriculture]-d[bacteria]-c[copper-bacteria]",
     inventory_move_sound = space_age_item_sounds.agriculture_inventory_move,
     pick_sound = space_age_item_sounds.agriculture_inventory_pickup,
     drop_sound = space_age_item_sounds.agriculture_inventory_move,
@@ -720,7 +720,7 @@ data:extend(
       { size = 64, filename = "__space-age__/graphics/icons/iron-bacteria-3.png", scale = 0.5, mipmap_count = 4 },
     },
     subgroup = "agriculture-processes",
-    order = "b[agriculture]-c[iron-bacteria]",
+    order = "b[agriculture]-d[bacteria]-a[iron-bacteria]",
     inventory_move_sound = space_age_item_sounds.agriculture_inventory_move,
     pick_sound = space_age_item_sounds.agriculture_inventory_pickup,
     drop_sound = space_age_item_sounds.agriculture_inventory_move,
@@ -1099,7 +1099,7 @@ data:extend(
     spoil_ticks = 0.5 * hour,
     spoil_to_trigger_result =
     {
-      items_per_trigger = 5, -- per 5 items the trigger is run
+      items_per_trigger = 25,
       trigger =
       {
         type = "direct",
@@ -1115,6 +1115,7 @@ data:extend(
               show_in_tooltip = true,
               as_enemy = true,
               find_non_colliding_position = true,
+              abort_if_over_space = true,
               offset_deviation = {{-1, -1}, {1, 1}},
               non_colliding_fail_result =
               {
@@ -1181,6 +1182,7 @@ data:extend(
               show_in_tooltip = true,
               as_enemy = true,
               find_non_colliding_position = true,
+              abort_if_over_space = true,
               offset_deviation = {{-5, -5}, {5, 5}},
               non_colliding_fail_result =
               {
@@ -1482,6 +1484,7 @@ data:extend(
                 {
                   type = "beam",
                   beam = "chain-tesla-gun-beam-start",
+                  source_offset = {0, -1.31439 },
                   max_length = 30,
                   duration = 30,
                   add_to_shooter = false,
@@ -1680,8 +1683,8 @@ data:extend(
       { size = 64, filename = "__space-age__/graphics/icons/tree-seed-3.png", scale = 0.5, mipmap_count = 4 },
       { size = 64, filename = "__space-age__/graphics/icons/tree-seed-4.png", scale = 0.5, mipmap_count = 4 },
     },
-    subgroup = "agriculture-processes",
-    order = "a[seeds]-c[tree-seed]",
+    subgroup = "nauvis-agriculture",
+    order = "a[seeds]-b[tree-seed]",
     plant_result = "tree-plant",
     place_result = "tree-plant",
     inventory_move_sound = item_sounds.wood_inventory_move,
